@@ -1,13 +1,14 @@
 from __future__ import unicode_literals
 
-from conllu.compat import FileNotFoundError, string_to_file
+from io import StringIO
+
 from conllu.models import TokenList
 from conllu.parser import parse_conllu_plus_fields, parse_sentences, parse_token_and_metadata
 
 
 def parse(data, fields=None, field_parsers=None, metadata_parsers=None):
     return list(parse_incr(
-        string_to_file(data),
+        StringIO(data),
         fields=fields,
         field_parsers=field_parsers,
         metadata_parsers=metadata_parsers
@@ -29,7 +30,7 @@ def parse_incr(in_file, fields=None, field_parsers=None, metadata_parsers=None):
         ))
 
 def parse_tree(data):
-    return list(parse_tree_incr(string_to_file(data)))
+    return list(parse_tree_incr(StringIO(data)))
 
 def parse_tree_incr(in_file):
     for tokenlist in parse_incr(in_file):
